@@ -21,6 +21,10 @@ pipelineLogger.setLevel(logging.DEBUG)
 class RedisSourceSettings(SourceSettings):
     redis: str = Field("redis://localhost:6379/0", title="redis url")
     group: str = Field(None, title="redis consumer group name")
+    min_idle_time: int = Field(
+        3600000,
+        title="messages not acknowledged after min-idle-time will be reprocessed",
+    )
 
 
 class RedisStreamSource(SourceTap):
@@ -63,24 +67,47 @@ class RedisStreamSource(SourceTap):
             raise
 
         timedOut = False
-        lastMessageBaseTime = time.time()
+        last_message_time = time.time()
+
         while not timedOut:
             try:
-                msg = self.redis.xreadgroup(
-                    self.group, self.consumer, {self.topic: ">"}, count=1
+                # claim lost pending messages
+                msg = self.redis.xautoclaim(
+                    self.group, self.consumer, self.settings.min_idle_time, "0", count=1
                 )
+
                 if msg:
-                    (msgId, data) = msg[0][1][0]
+                    (msgId, data) = msg[0]
+                else:
+                    # if no lost pending message, read new message
+                    msg = self.redis.xreadgroup(
+                        self.group, self.consumer, {self.topic: ">"}, count=1
+                    )
+                    if msg:
+                        (msgId, data) = msg[0][1][0]
+                    else:  # no message
+                        data = None
+
+                # for either old or new message
+                if data:
                     self.last_msg = msgId
                     self.logger.info("Read message %s", msgId)
                     yield MessageBase.deserialize(data[b"data"])
-                    lastMessageBaseTime = time.time()
+                    last_message_time = time.time()
+
             except Exception as ex:
                 self.logger.error(ex)
                 break
             time.sleep(0.01)
-            if self.timeout > 0 and time.time() - lastMessageBaseTime > self.timeout:
-                timedOut = True
+            if self.timeout > 0:
+                elapsed_time = time.time() - last_message_time
+                if elapsed_time > self.timeout:
+                    self.logger.warning(
+                        "reader timed out after %d seconds (timeout %d)",
+                        elapsed_time,
+                        self.timeout,
+                    )
+                    timedOut = True
 
     def acknowledge(self) -> None:
         self.logger.info("acknowledged message %s", self.last_msg)
@@ -168,7 +195,7 @@ class RedisListSource(SourceTap):
 
     def read(self) -> Iterator[MessageBase]:
         timedOut = False
-        lastMessageBaseTime = time.time()
+        last_message_time = time.time()
         while not timedOut:
             try:
                 value = self.redis.lpop(self.topic)
@@ -176,13 +203,20 @@ class RedisListSource(SourceTap):
                     msg = MessageBase.deserialize(value)
                     self.logger.info("Read message %s", str(msg))
                     yield msg
-                    lastMessageBaseTime = time.time()
+                    last_message_time = time.time()
             except Exception as ex:
                 self.logger.error(ex)
                 break
             time.sleep(0.01)
-            if self.timeout > 0 and time.time() - lastMessageBaseTime > self.timeout:
-                timedOut = True
+            if self.timeout > 0:
+                elapsed_time = time.time() - last_message_time
+                if elapsed_time > self.timeout:
+                    self.logger.warning(
+                        "reader timed out after %d seconds (timeout %d)",
+                        elapsed_time,
+                        self.timeout,
+                    )
+                    timedOut = True
 
     def acknowledge(self) -> None:
         self.logger.info("Acknowledgement is not supported for LREDIS (Redis List)")
