@@ -247,7 +247,7 @@ class FileSource(SourceTap):
 class FileDestinationSettings(DestinationSettings):
     filename: str = Field(None, title="output filename", required=True)
     overwrite: bool = Field(False, title="overwrite output file if exists")
-    content_only: bool = Field(False, title="input contains only content for messages")
+    content_only: bool = Field(False, title="output content only, no messages")
 
 
 class FileDestination(DestinationTap):
@@ -502,6 +502,26 @@ def tap_kinds() -> Dict[
                 settings_class="pipeline.backends.rabbitmq:RabbitMQDestinationSettings",
             ),
         ),
+        "ELASTIC": (
+            TapAndSettingsImportStrings(
+                tap_class="pipeline.backends.elasticsearch:ElasticSearchSource",
+                settings_class="pipeline.backends.elasticsearch:ElasticSearchSourceSettings",
+            ),
+            TapAndSettingsImportStrings(
+                tap_class="pipeline.backends.elasticsearch:ElasticSearchDestination",
+                settings_class="pipeline.backends.elasticsearch:ElasticSearchDestinationSettings",
+            ),
+        ),
+        "MONGO": (
+            TapAndSettingsImportStrings(
+                tap_class="pipeline.backends.mongodb:MongodbSource",
+                settings_class="pipeline.backends.mongodb:MongodbSourceSettings",
+            ),
+            TapAndSettingsImportStrings(
+                tap_class="pipeline.backends.mongodb:MongodbDestination",
+                settings_class="pipeline.backends.mongodb:MongodbDestinationSettings",
+            ),
+        ),
     }
 
 
