@@ -1,4 +1,5 @@
 import tempfile
+import re
 from unittest import mock
 
 from pydantic import BaseModel, Field
@@ -102,9 +103,30 @@ class TestWorkerCore:
         msgs = [{"key": 1}, {"key": 2}, {"key": 3}]
         processor.parse_args()
         processor.source.data = msgs
+        assert processor.has_output() is True
         with pytest.raises(PipelineOutputError):
             processor.start()
 
+    def test_processor_has_output(self):
+        class Input(BaseModel):
+            key: str
+
+        class MyProcessor(Processor):
+            def process(self, input, id):
+                pass
+
+        settings = ProcessorSettings(
+            name="processor",
+            version="0.0.0",
+            description="",
+            monitoring=True,
+        )
+        processor = MyProcessor(settings, input_class=Input, output_class=None)
+        processor.parse_args(
+            args="--in-kind MEM --out-kind MEM --out-topic test".split()
+        )
+        assert processor.has_output() is False
+
     def test_processor_invalid_input(self):
         class Output(BaseModel):
             language: str
@@ -495,3 +517,27 @@ class TestWorkerCore:
         assert definition2.source.topic == "in-topic"
 
         assert definition1 == definition2
+
+    def test_help(self, capfd):
+        class Input(BaseModel):
+            pass
+
+        class Output(BaseModel):
+            pass
+
+        class MyProcessor(Processor):
+            def process(self, msg: Input, id: str) -> Output:
+                return Output()
+
+        settings = ProcessorSettings(
+            name="processor",
+            version="0.0.0",
+            description="",
+        )
+        processor = MyProcessor(settings, input_class=Input, output_class=Output)
+        with pytest.raises(SystemExit):
+            processor.parse_args(
+                args=["--help", "--in-kind", "FILE", "--out-kind", "FILE"]
+            )
+        out, err = capfd.readouterr()
+        assert re.search("--in-filename", out)
